#
# spec file for package perl-Class-Load
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Class-Load
Name:           perl-Class-Load
Version:        0.250.0
Release:        1.2
# 0.25 -> normalize -> 0.250.0
%define cpan_version 0.25
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Working (require "Class::Name") and more
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/E/ET/ETHER/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Data::OptList) >= 0.110
BuildRequires:  perl(Module::Implementation) >= 0.40
BuildRequires:  perl(Module::Runtime) >= 0.12
BuildRequires:  perl(Package::Stash) >= 0.140
BuildRequires:  perl(Test::Fatal)
BuildRequires:  perl(Test::More) >= 0.88
BuildRequires:  perl(Test::Needs)
BuildRequires:  perl(Try::Tiny)
BuildRequires:  perl(version)
Requires:       perl(Data::OptList) >= 0.110
Requires:       perl(Module::Implementation) >= 0.40
Requires:       perl(Module::Runtime) >= 0.12
Requires:       perl(Package::Stash) >= 0.140
Requires:       perl(Try::Tiny)
Provides:       perl(Class::Load) = %{version}
Provides:       perl(Class::Load::PP) = %{version}
%undefine       __perllib_provides
%{perl_requires}

%description
'require EXPR' only accepts 'Class/Name.pm' style module names, not
'Class::Name'. How frustrating! For that, we provide 'load_class
'Class::Name''.

It's often useful to test whether a module can be loaded, instead of
throwing an error when it's not available. For that, we provide
'try_load_class 'Class::Name''.

Finally, sometimes we need to know whether a particular class has been
loaded. Asking '%INC' is an option, but that will miss inner packages and
any class for which the filename does not correspond to the package name.
For that, we provide 'is_class_loaded 'Class::Name''.

%prep
%autosetup -n %{cpan_name}-%{cpan_version} -p1

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes CONTRIBUTING README
%license LICENSE

%changelog
* Mon Jun 23 2025 Tina Müller <tina.mueller@suse.com>
- Normalize CPAN version
  See https://github.com/openSUSE/cpanspec/issues/47 for details
* Mon Jun 11 2018 coolo@suse.com
- updated to 0.25
  see /usr/share/doc/packages/perl-Class-Load/Changes
  0.25     2018-06-10 20:55:10Z
  - merged required and recommended Data::OptList version prerequisite, to
    work around CPAN.pm bug (RT#123447)
* Tue Apr 11 2017 coolo@suse.com
- updated to 0.24
  see /usr/share/doc/packages/perl-Class-Load/Changes
  0.24     2017-04-10 21:12:31Z
  - fix test to handle altered Test::Without::Module exception message
    (PR#2, Paul Howarth)
* Sat Jun 27 2015 coolo@suse.com
- updated to 0.23
  see /usr/share/doc/packages/perl-Class-Load/Changes
  0.23     2015-06-25
  - remove use of namespace::clean
* Thu Apr 16 2015 coolo@suse.com
- updated to 0.22
  see /usr/share/doc/packages/perl-Class-Load/Changes
  0.22     2014-08-16
  - document some of the caveats to using this module, and refer to
    Module::Runtime as an alternative
* Sun Feb  9 2014 coolo@suse.com
- updated to 0.21
  - repository moved to the github moose organization
* Mon Jun 10 2013 coolo@suse.com
- remove outdated patch perl-Class-Load-old_test_more.patch
* Mon Jun  3 2013 coolo@suse.com
- updated to 0.20
  - The load_class() subroutine now returns the class name on success. Requested
    by Caleb Cushing. RT #76931.
  - Exceptions and errors from Class::Load no longer contain references to line
    numbers in Class::Load or Module::Runtime. This applies to exceptions thrown
    by load_class, load_first_existing_class, and load_optional_class, as well
    as the error returned by try_load_class.
  - Exceptions are now croaked properly so they appear to come from the calling
    code, not from an internal subroutine. This makes the exceptions look more
    like the ones thrown by Perl's require. RT #68663.
* Thu Mar  1 2012 ro@suse.de
- fix build with old Test::More on sle11
* Tue Feb 21 2012 coolo@suse.com
- updated to 0.18
  - Require Package::Stash 0.14+. Fixes RT#75095. Reported by Zefram.
* Mon Feb 13 2012 coolo@suse.com
- updated to 0.17
  - A bug in Class::Load caused test failures when Module::Runtime 0.012 was
  used with Perl 5.8.x. Reported by Zefram. RT#74897. ( Jesse Luehrs )
  - Require Module::Runtime 0.012, which has a number of useful bug fixes.
  - Small test changes to accomodate latest version of
  Module::Implementation. There's no need to upgrade if you're already using
  0.14
  - Use Module::Implementation to handle loading the XS or PP versions of the
  code. Using this module fixes a few bugs.
  - Under taint mode, setting an implementation in the CLASS_LOAD_IMPLEMENTATION
  env var caused a taint error.
  - An invalid value in the CLASS_LOAD_IMPLEMENTATION env var is now detected
  and reported immediately. No attempt is made to load an invalid
  implementation.
  - Fix some bugs with our use of Try::Tiny. This could cause warnings on some
  systems with Class::Load::XS wasn't installed. Fixes RT#72345.
* Tue Nov 29 2011 lars@linux-schulserver.de
- update to 0.12:
  + Depend on Module::Runtime 0.011+. This fixes problems with
    Catalyst under Perl 5.8 and 5.10.
* Wed Oct 26 2011 tabraham@novell.com
- updated to 0.11 2011-10-04
  - don't accept package names that start with a digit ( Jesse Luehrs )
  - rewrote some of the guts to use Module::Runtime, rather than
    reimplementing its functionality ( Jesse Luehrs )
- updated to 0.10 2011-09-06
  - make sure the $@ localization doesn't hide errors - invalid
    module name errors were being suppressed on perls before 5.14
    ( Jesse Luehrs )
- Updated to 0.09 2011-09-05
  - fix is_class_loaded to ignore $ISA (but still look for @ISA)
    when trying to determine whether a class is loaded ( Jesse Luehrs )
  - lots of internals cleanup ( Jesse Luehrs )
- updated to 0.08 2011-08-15
  - the previous version was missing a prereq declaration for
    Data::OptList. Reported by Daisuke Maki and Mark Hedges. RT #70285.
- updated to 0.07 2011-08-15
  - All this module's subroutines now accept optional parameters for a
    module so you can write something like -
    load_class( 'Foo', { -version => 42 } )
  - There is now a Class::Load::XS distro available on CPAN which implements
    some of this module's code in XS for speed. This code was originally written
    by Goro Fuji and Florian Ragwitz for Class::MOP. You need to install this
    distro explicitly if you want the XS implementation.
  - added a load_first_existing_class subroutine based mostly borrowed from
    Class::MOP
  - fixed a bug where a package with a version object in it's $VERSION would
    not be seen as loaded. Reported by Chris Prather.
* Wed Dec 29 2010 pascal.bleser@opensuse.org
- initial version (0.06)
